@@ -5,14 +5,14 @@ class Config(metaclass=Singleton):
     FIELD_VALUE = 0
     FIELD_DESCRIPTION = 1
 
-    baseConfigFileName = '../base.cfg'
-    def __init__(self):
+    def __init__(self, configFileName):
+        self.configFileName = configFileName
         self.configs = self.__load()
 
     def __load(self):
         configs = {}
-        if os.path.exists(self.baseConfigFileName):
-            with open(self.baseConfigFileName, 'r') as f:
+        if os.path.exists(self.configFileName):
+            with open(self.configFileName, 'r') as f:
                 data = f.read().split('\n')
             for d in data:
                 description = ''
