@@ -9,10 +9,14 @@ class Util:
         if withTimerDisplay == True:
             now = dt.datetime.now()
             while until > now:
-                print ('{}\r'.format(now.strftime('%Y-%m-%d %H:%M:%S')), end='')
-                sys.stdout.flush()
+                Util.prompt(now.strftime('%Y-%m-%d %H:%M:%S'))
                 time.sleep(1)
                 now = dt.datetime.now()
+    
+    @classmethod
+    def prompt(self, message):
+        print ('{}\r'.format(message), end='')
+        sys.stdout.flush()
 
 if __name__ == '__main__':
     util = Util.wait(dt.datetime.now()+dt.timedelta(seconds=20))
\ No newline at end of file
